@@ -28,21 +28,21 @@ def act__signup(name: str = None, pw: str = None) -> dict:
     if pw is None:
         pw = 'password'
     resp = post__signup(name, pw, ATestRequest(True))
-    assert resp[AA.HttpStatus] == HttpStatus.Created_201.value
-    uid: str = resp[AA.Data][AA.UserId]
-    return {
-        AA.Name: name,
-        AA.Password: pw,
-        AA.UserId: uid,
-        AA.Response: resp
-    }
-
-
-def act__signup___error(name: str = None, pw: str = None) -> dict:
-    if name is None:
-        name = new_rand_test_user_name()
-    if pw is None:
-        pw = 'password'
-    resp = post__signup(name, pw, ATestRequest(True))
-    assert AA.___Error___ in resp
+    if resp[AA.Data] is not None:
+        assert resp[AA.HttpStatus] == HttpStatus.Created_201.value
+        resp[AA.Name] = name
+        resp[AA.Password] = pw
+        resp[AA.UserId] = resp[AA.Data][AA.UserId]
+        return resp
+    else:
+        assert AA.___Error___ in resp
     return resp
+
+# def act__signup___error(name: str = None, pw: str = None) -> dict:
+#     if name is None:
+#         name = new_rand_test_user_name()
+#     if pw is None:
+#         pw = 'password'
+#     resp = post__signup(name, pw, ATestRequest(True))
+#     assert AA.___Error___ in resp
+#     return resp
